tonalanalysistools.ChordSuspension
==================================

.. abjad-lineage:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension

.. autoclass:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.chord_name
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.figured_bass_pair
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.figured_bass_string
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.is_empty
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.start
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.stop
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.title_string
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__eq__
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__format__
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__ne__
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__repr__
      ~abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.chord_name
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.figured_bass_pair
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.figured_bass_string
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.is_empty
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.start
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.stop
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.title_string
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordSuspension.ChordSuspension.__str__
   :noindex:
